unit SDIMAIN;

interface

uses Windows, Classes, Graphics, Forms, Controls, Menus,
  Dialogs, StdCtrls, Buttons, ExtCtrls, ComCtrls, ImgList, StdActns,
  ActnList, ToolWin, SysUtils;

const
  LWZ_MAX_DEVICES : Integer = 16;
  LWZ_ADD : Integer = 1;
  LWZ_DELETE : Integer = 2;

type
  TfrmLEDWizDLLTest = class(TForm)
    GroupBox1: TGroupBox;
    txtBank1: TEdit;
    Label1: TLabel;
    txtBank2: TEdit;
    txtBank3: TEdit;
    txtBank4: TEdit;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    txtGlobalPulse: TEdit;
    Label5: TLabel;
    btnSetSBA: TButton;
    Label6: TLabel;
    lstDevice: TComboBox;
    GroupBox2: TGroupBox;
    btnSetPBA: TButton;
    txtPBA: TEdit;
    btnAll48: TButton;
    btnAll0: TButton;
    btnSPBAll255: TButton;
    btnSBAAll0: TButton;
    lblDetectedDevices: TLabel;
    Label7: TLabel;
    procedure FormShow(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure btnAll48Click(Sender: TObject);
    procedure btnAll0Click(Sender: TObject);
    procedure btnSPBAll255Click(Sender: TObject);
    procedure btnSBAAll0Click(Sender: TObject);
    procedure btnSetPBAClick(Sender: TObject);
    procedure btnSetSBAClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

type
  LWZHANDLE = THandle;
  TLWZNOTIFYPROC = Procedure(reason: Integer; newDevice: LWZHANDLE) stdcall;

type
  PLWZDEVICELIST = ^LWZDEVICELIST;
  LWZDEVICELIST = packed record
    handles: Array[0..15] of THandle;
    numdevices: Integer;
  end;

Procedure LWZ_SBA(device: LWZHANDLE; bank0, bank1, bank2, bank3: Cardinal; globalPulseSpeed: Cardinal) cdecl; external 'ledwiz.dll';
Procedure LWZ_PBA(device: LWZHANDLE; brightness: Pointer) cdecl; external 'ledwiz.dll';
Procedure LWZ_REGISTER(device: LWZHANDLE; hWnd: HWND) cdecl; external 'ledwiz.dll';
Procedure LWZ_SET_NOTIFY(notifyProc: TLWZNOTIFYPROC; list: PLWZDEVICELIST) cdecl; external 'ledwiz.dll';

var
  frmLEDWizDLLTest: TfrmLEDWizDLLTest;
  hWndForm: HWND;
  deviceList: LWZDEVICELIST;
  pdeviceList: PLWZDEVICELIST = @deviceList;
  brightness: array[0..31] of byte;
  bQuiting: boolean;
  DeviceHandleIndex: array[1..16] of integer;

implementation

{$R *.dfm}

function ConvertPBAString(const sPBA: string; out aPBAVals: array of byte): boolean;
var
  nIndex: integer;
  slistBuf: TStringList;
begin
  //sPBA must be a comma seperated list of LEDWiz profile values.
  slistBuf := TStringList.Create;
  slistBuf.CommaText := sPBA;
  if slistBuf.Count <> 32 then
  begin
    result := false;
    exit;
  end;

  for nIndex := 0 to 31 do
    aPBAVals[nIndex] := StrToInt(slistBuf[nIndex]);
    
  slistBuf.Free;
  result := true;
end;

Procedure notify(reason: Integer; newDevice: LWZHANDLE) stdcall;
var
  nIndex: integer;
Begin
  if (reason = LWZ_ADD) then
  begin
    LWZ_REGISTER(newDevice, hWndForm);
  end;

  if bQuiting then exit;

  with frmLEDWizDLLTest do
  begin
    lblDetectedDevices.Caption := '';
    for nIndex := 0 to deviceList.numdevices - 1 do
    begin
      DeviceHandleIndex[deviceList.handles[nIndex]] := nIndex;
      lblDetectedDevices.Caption := lblDetectedDevices.Caption + ' ' + IntToStr(deviceList.handles[nIndex]);
    end;
  end;
End;

procedure TfrmLEDWizDLLTest.btnAll0Click(Sender: TObject);
begin
  txtPBA.Text := '0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0';
end;

procedure TfrmLEDWizDLLTest.btnAll48Click(Sender: TObject);
begin
  txtPBA.Text := '48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48';
end;

procedure TfrmLEDWizDLLTest.btnSBAAll0Click(Sender: TObject);
begin
  txtBank1.Text := '0';
  txtBank2.Text := '0';
  txtBank3.Text := '0';
  txtBank4.Text := '0';
end;

procedure TfrmLEDWizDLLTest.btnSetPBAClick(Sender: TObject);
begin
    if ConvertPBAString(txtPBA.Text,brightness) then
      LWZ_PBA(deviceList.handles[DeviceHandleIndex[StrToInt(lstDevice.Text)]],addr(brightness[0]));

end;

procedure TfrmLEDWizDLLTest.btnSetSBAClick(Sender: TObject);
begin
    LWZ_SBA(deviceList.handles[DeviceHandleIndex[StrToInt(lstDevice.Text)]], StrToInt(txtBank1.Text), StrToInt(txtBank2.Text), StrToInt(txtBank3.Text), StrToInt(txtBank4.Text), StrToInt(txtGlobalPulse.Text));

end;

procedure TfrmLEDWizDLLTest.btnSPBAll255Click(Sender: TObject);
begin
  txtBank1.Text := '255';
  txtBank2.Text := '255';
  txtBank3.Text := '255';
  txtBank4.Text := '255';
end;

procedure TfrmLEDWizDLLTest.FormClose(Sender: TObject; var Action: TCloseAction);
var
  I: Integer;
begin
  bQuiting := true;
  for I := 0 to deviceList.numdevices - 1 do
  begin
    LWZ_SBA(deviceList.handles[I], 0, 0, 0, 0, 2);
  end;
end;

procedure TfrmLEDWizDLLTest.FormShow(Sender: TObject);
var
  I: Integer;
begin
  hWndForm := self.Handle;

  for I := 1 to 16 do
    DeviceHandleIndex[I] := 99;

  LWZ_SET_NOTIFY(@notify, pdeviceList);

  {
  for I := 0 to 31 do
  begin
     brightness[I] := 48;
  end;

  for I := 0 to deviceList.numdevices - 1 do
  begin
    LWZ_PBA(deviceList.handles[I], Addr(brightness[0]));
    LWZ_SBA(deviceList.handles[I], 255, 255, 255, 255, 2);
  end;
  }
end;

end.

